@@ -46,9 +46,11 @@ class Network3Medusa():
                 if first:
                     first = False
                     raw_json=line
-                    self.add_file_to_hedera(line)
+                    print(raw_json)
+                    self.add_file_to_hedera(raw_json)
                 else:
-                    self.append_file_to_hedera(line)
+                    print(raw_json)
+                    self.append_file_to_hedera(raw_json)
             query = FileInfoQuery().setFileId(self.fileId)
             info = query.execute(self.client)
             print("File size according to `FileInfoQuery`: ", info.size)
@@ -79,7 +81,7 @@ class Network3Medusa():
         tran = (FileAppendTransaction()
                 .setFileId(self.fileId)
                 .setContents(interface)
-                .setMaxChunks(128)
+                .setMaxChunks(500)
                 .setMaxTransactionFee(Hbar(2))
                 .freezeWith(self.client))
         resp = tran.execute(self.client)
